//       1         2         3         4         5         6         7
// 4567890123456789012345678901234567890123456789012345678901234567890123456789

package la.la;
// ----------------------------------------------------------------------------

/* Copyright (c) 2018 Lloyd Allison.

   Reference: 
     Lloyd Allison, "Coding Ockham's Razor", Springer, 2018.

   This file is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License (GPL) as published
   by the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This file is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this file. If not, see http://www.gnu.org/licenses/
 */
// ----------------------------------------------------------------------------

/** Declaration specifies the abstract syntax (parse tree) of
    <NOBR> <TT> [rec] x0=e0, x1=e1, ... </TT>; </NOBR>
    also see {@link Expression} and {@link Value}.  */
public class Declaration
 { /** Are these Declarations recursive, or not? */
   public final boolean isRec;
   /** The identifiers bound to Expressions 'es'. */
   public final String     [] ids;  // {x0, x1, ...}
   /** The Expressions (Values) bound to the identifiers, 'ids'. */
   public final Expression [] es;   // {e0, e1, ...}

   /** Create a, possibly recursive (isRec?), Declaration binding
       identifier ids[0] to Expression es[0], and so on;
       also see {@link Expression.Block}.  */
   public Declaration(boolean isRec, String [] ids, Expression [] es)
    { this.isRec = isRec; this.ids = ids; this.es = es;
      if( ids.length != es.length || ids.length < 1 )
         error("|ids|=" + ids.length + " |es|=" + es.length);
    }//constructor

   /** For printing; also see {@link Expression#appendSB}. */
   public void appendSB(StringBuffer sb)
    { sb.append( isRec ? Lexical.Symbol[Lexical.recSy]+" " : "" );
      for( int i = 0; i < ids.length; i ++ )
       { sb.append( ids[i] + " = "); es[i].appendSB(sb);
	 sb.append((i < ids.length-1 ? "," : "") + "\n");
    }  }

   void error(String msg)
    { throw new RuntimeException("Declaration: " + msg); }

 }//Declaration class

// Lambda, (c) Lloyd Allison, October 2007, 2012. Licence is Gnu GPL.
