//       1         2         3         4         5         6         7
// 4567890123456789012345678901234567890123456789012345678901234567890123456789

package la.la;
// ----------------------------------------------------------------------------

/* Copyright (c) 2018 Lloyd Allison.

   Reference: 
     Lloyd Allison, "Coding Ockham's Razor", Springer, 2018.

   This file is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License (GPL) as published
   by the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This file is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this file. If not, see http://www.gnu.org/licenses/
 */
// ----------------------------------------------------------------------------

/** Wrapper for the interpreter, bringing Syntax and Semantics together. */
public class FP
 { private static final long t0 = System.currentTimeMillis();

   /** The current running time in seconds (to 0.001). */
   public static double currentSecs()
    { return (System.currentTimeMillis() - t0) / 1000.0; }

   public static void main(String[] argv)
    { System.out.println("-- Lambda --");
      for(int i=0; i < argv.length; i++) // command line params if any
         System.out.print("argv[" + i + "]=" + argv[i] + "\n");

      try
       { Lexical lex = argv.length <= 0 ? new Lexical(System.in)
                     : Lexical.forFile(new java.io.File(argv[0]));
         Syntax syn = new Syntax( lex );
         Expression e = syn.exp();                       // parse an Expression

         System.out.println("-- Expression --");
         System.out.println( e.toString() );

         System.out.println("-- Running --");       // evaluation is IO driven
         e.defer(Environment.initial).print(System.out);
       }
      catch(RuntimeException e)
       { System.out.println( "\nError " + e.getMessage() ); }

      System.out.println( "\n-- Lambda stop ("
         + new java.text.DecimalFormat("0.0").format(currentSecs())
         + "s.), L.Allison 2012 www.allisons.org/ll/ --" );
    }//main

 }//FP class       http://www.allisons.org/ll/

// Lambda, (c) Lloyd Allison, October 2007, 2012.
