//       1         2         3         4         5         6         7
// 4567890123456789012345678901234567890123456789012345678901234567890123456789

package mml;

import la.la.Value;
import la.la.Value.*;
// import la.la.Function;
import la.maths.Vector;
import la.maths.Vector.Slice;

// ----------------------------------------------------------------------------

/* Copyright (c) 2018 Lloyd Allison.

   Reference:
     Lloyd Allison, "Coding Ockham's Razor", Springer, 2018.

   This file is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License (GPL) as published
   by the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This file is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this file. If not, see http://www.gnu.org/licenses/
 */
// ----------------------------------------------------------------------------

/** <U>Experimental, may change or disappear</U>:
    Heavy-tailed continuous probability distribution(s). */
public class HeavyTail                                             // HeavyTail
 {
   /** A heavy-tailed, log-symmetric, everywhere differentiable,
       probability distribution for continuous (real-valued) X&gt;0.
       No estimator has been, nor is likely to be, implemented.
       The fully parameterised Over_x1 Model is {@link M} and
       its pdf is specified by {@link M#pdf_x pdf_x(x)}.  */
   public static class Over_x1 extends Continuous                    // Over_x1
    { /** No non-trivial problem-defining parameters; t=triv.  */
      public Over_x1(Value t)
       { super(t); if( t != triv ) error( ", t!=triv" ); } //constructor

      /** Sufficient statistics, ss&nbsp;=&nbsp;stats(ds,lo,hi), of elements
          [lo,hi) of a data-set ds; here ss&nbsp;=&nbsp;ds.[lo,hi).
          More on stats {@link UPModel#stats here}. */
      public Vector stats(Vector ds, int lo, int hi)
       { return ds.slice(lo, hi); }

      public Vector stats(boolean add, Value ss0, Value ss1)
       { return ((Vector) ss0).combine(add, (Slice) ss1); }

      public M sp2Model(double msg1, double msg2, Value sp)
       { return new M(msg1, msg2, sp); }
      // ...............................

      /** The fully parameterised {@link Over_x1 Over_x1} Model; see
          {@link #pdf_x pdf_x(x)}. The statistical parameter delta&gt;1. */
      public class M extends Continuous.M                          // Over_x1.M
       { /** The double version of &delta;&gt;1, and
             the normalising constant&nbsp;'k'.
             See {@link #f f(x)} and {@link #pdf_x pdf_x(x)}.  */
         protected double delta_x, k;

         /** Real-valued &delta;&gt;1. The closer &delta; is to 1.0, the
             closer the distribution is to (something like) 1/x.
             See {@link #f f(x)}.  */
         public M(double msg1, double msg2, Value delta)
          { super(msg1, msg2, delta);
            delta_x = delta.x();
            k = (delta_x - 1.0) / 2.0;
            if( delta_x <= 1 ) error( "delta=" + delta );
          }//constructor

         /** A log-symmetric probability density function.
             Now, pdf<SUB>1</SUB>(x)=(&delta;&minus;1)*{@link #f f(x)}
             is a valid pdf but is not log-symmetric.
             However, let y=1/x then dy/dx=&minus;1/x<SUP>2</SUP>,
             pdf<SUB>2</SUB>(x)=pdf<SUB>1</SUB>(1/x)/x<SUP>2</SUP>.
             Then pdf(x)=(pdf<SUB>1</SUB>(x)+pdf<SUB>2</SUB>(x))/2
             is log-symmetric:
             &int;<SUB>[a,b]</SUB>pdf(x)&nbsp;ds =
             &int;<SUB>[1/b..1/a]</SUB>pdf(1/x)&nbsp;dx.
             Also&nbsp;see&nbsp;{@link #f f(x)}. */
         public double pdf_x(double x)                              // pdf_x(x)
          { return k * (f(x) + f(1.0/x)/(x*x)); }

         /** The negative log of {@link #pdf_x pdf_x(x)}.  */
         public double nlPdf_x(double x)                          // nlPdf_x(x)
          { return - Math.log( pdf_x(x) ); }

         /** f(x) = 1/(1+x)<SUP>&delta;</SUP>,&nbsp; where &delta;&gt;1.
             The integral, &int;<SUB>0..&infin;</SUB>f(x) =
         [&minus;1/((&delta;-1)(1+x)<SUP>&delta;-1</SUP>)]<SUB>0..&infin;</SUB>
             =&nbsp;1/(&delta;&minus;1).&nbsp;
             f(x)&nbsp;is used by {@link #pdf_x pdf_x(x)}.  */
         protected double f(double x)                                   // f(x)
          { return 1.0 / Math.exp( delta_x * Math.log(1+x) ); }

         /** The negative log likelihood, nlLH(ss), of a data-set ds
             having statistics ss=stats(ds) (=&nbsp;ds itself).  */
         public double nlLH(Value ss)
          { return sumNlPr((Vector) ss); }

       }//Over_x1.M class, the Model

    }//Over_x1 class, the UPModel

 }//HeavyTail class

// (c) Lloyd Allison 30 Dec 2019. Licence to 'HeavyTail' is GNU GPL.
