package mml;

/**

<P>About package '<B>mml</B>' &mdash;
tools for Minimum Message Length inference.
</P>

<UL>
<LI>{@link MML}       &mdash; core constants, functions and Models, including
    <UL>
    <LI> <!--  style="margin:0 0 0 50px" -->
        {@link MML#Known       Known},
        {@link MML#Geometric0  Geometric0},
        {@link MML#logStar0    logStar0},
        {@link MML#WallaceInt0 WallaceInt0},
        {@link MML#Poisson0    Poisson0},
        {@link MML#Normal      Normal} (Gaussian),
        {@link MML#N01         N01} (&mu;=0, &sigma;=1),
        {@link MML#Laplace     Laplace},
        {@link MML#vMF3        vMF3} (von&nbsp;Mises Fisher in 3-D),
        etc
    </UL>
  <LI>{@link UPModel}      &mdash; unparameterised statistical Models
  <LI>{@link Model}        &mdash; fully parameterised statistical Models
      (also {@link UPModel.M})
  <LI>{@link Estimator}    &mdash; estimate a fully parameterised
                                   statistical Model
      (also {@link UPModel.Est})
  <LI>{@link UPFunctionModel} &mdash; unparameterised Function-Models
  <LI>{@link FunctionModel}   &mdash; fully parameterised Function-Models
      (also {@link UPFunctionModel.M})
  <LI>{@link UPSeriesModel}   &mdash; unparameterised Series-Models
  <LI>{@link SeriesModel}     &mdash; fully parameterised Series-Models
      (also {@link UPSeriesModel.M})
  <LI> etc<BR> <BR>
  <LI>{@link Discretes}    &mdash; models of discrete data
  <LI>{@link MultiState}   &mdash; models of Bernoulli trials &ndash;
                                   coins, dice and the like
  <LI>{@link Continuous}   &mdash; models of continuous, <B>R</B>, data
  <LI>{@link R_D}          &mdash; models of multivariate
                                  continuous, <B>R</B><SUP>D</SUP>, data
  <LI>{@link Multinomial}
  <LI>{@link CPT}          &mdash; Conditional Probability Tables
  <LI>{@link Multivariate}
  <LI>{@link Intervals}    &mdash; discretization
  <LI>{@link NaiveBayes}   &mdash; naive Bayes
  <LI>{@link Mixture}      &mdash; Mixture Models
  <LI>{@link Tree}    &mdash; decision- (classification-, regression-) Trees
  <LI>{@link Graphs}       &mdash; Models of Graphs (networks)
  <LI>{@link UPModel.Transform} &mdash; Transformed Models, e.g., log-Normal
  <LI> etc
</UL>

<P>Also see supporting package(s) [{@link la.README la}].</P>

<P><B>References</B>:</P>

  <UL>
  <LI> L.&nbsp;Allison,
       'Coding Ockham's Razor',
       Springer,&nbsp;<B>2018</B>,
       isbn13:&nbsp;978-3319764320,
       [<A HREF="https://doi.org/10.1007/978-3-319-76433-7"
              TARGET="BOOKA">doi:10.1007/978-3-319-76433-7</A>]

  <LI>L. Allison,
    'Models for machine learning and data mining in functional programming,'
    Journal&nbsp;of Functional Programming (JFP),
    15(1), pp.15-32, January&nbsp;2005,
    [<A HREF="https://doi.org/10.1017/S0956796804005301"
              TARGET="EX">doi:10.1017/S0956796804005301</A>]

  <LI>C. S. Wallace
    'Statistical and Inductive Inference by Minimum Message Length,'
    Springer (Information Science and Statistics),
    pp.432, May&nbsp;2005,
    [<A HREF="https://doi.org/10.1007/0-387-27656-4"
              TARGET="EX">doi:10.1007/0-387-27656-4</A>]

  <LI>C. S. Wallace &amp; D. M. Boulton,
    'An information measure for classification,'
    Computer&nbsp;Journal, 11(2), pp.185-194, August&nbsp;1968,
    [<A HREF="https://doi.org/10.1093/comjnl/11.2.185"
              TARGET="EX">doi:10.1093/comjnl/11.2.185</A>]

  <LI>Also see the
      [<A HREF="https://www.cantab.net/users/mmlist/MML/A/"
          TARGET="mmlist">home&nbsp;page</A>]
      www.cantab.net/users/mmlist/MML/A/
      for source-code releases.
  </UL>

<P><B>On Big Data</B>:
Note that MML is agnostic about
<SPAN STYLE="font-size:130%">big</SPAN> v
<SPAN STYLE="font-size:75%"><B>small</B></SPAN> data;
if you have an algorithm to efficiently calculate, or approximate,
the sufficient {@link UPModel#stats statistics} of a model and to calculate
a valid message length for a huge data-set, MML is amenable to that.
</P>

<P><B>Copyright</B> &copy; 2018 Lloyd Allison.
   Reference: Lloyd Allison, "Coding Ockham's Razor", Springer, 2018.

   This file is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License (GPL) as published
   by the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This file is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this file. If not, see http://www.gnu.org/licenses/
</P>

*/

public class README
 { public String toString()
    { return "see www.cantab.net/users/mmlist/MML/A/"; }
 }

// (c) Lloyd Allison, 2013, 20 Dec 2019. [See *.java for licence conditions.]
